@@ -404,7 +404,8 @@ class Mail(DocumentMixin, WBModel):
         )
 
         document_type, created = DocumentType.objects.get_or_create(name="mailing")
-        for name, payload, mimetype in attachments:
+        for attachment in attachments:
+            name, payload = attachment[0:2]
             # If an alternative sent from DMS is found, we match against the attachment email.
             dms_elements = list(filter(lambda x: x["filename"] == name, dms_alternatives))
             if (len(dms_elements) == 1) and (document_id := dms_elements[0].get("id", None)):
@@ -626,6 +627,9 @@ class MailEvent(models.Model):
         verbose_name = _("Mail Event")
         verbose_name_plural = _("Mail Events")
 
+    def __str__(self) -> str:
+        return f"{self.mail} - {self.event_type}"
+
     @classmethod
     def subquery_delivered_mails(cls, mass_mail_name="pk"):
         """
@@ -713,7 +717,7 @@ class MailTemplate(WBModel):
 
 
 @receiver(tracking)
-def handle_mail_tracking(sender, event, esp_name, **kwargs):
+def handle_mail_tracking(sender, event, esp_name, **kwargs):  # noqa: C901
     """
     Signal triggered by the Sendgrid sdk. Create MailEvent
     """
@@ -741,7 +745,7 @@ def handle_mail_tracking(sender, event, esp_name, **kwargs):
                         automatically_approve=automatically_approve,
                     )
 
-    def get_mail(message_id, tags=[]):
+    def get_mail(message_id, tags: list | None = None):
         mail = Mail.objects.filter(message_ids__contains=[event.message_id]).first()
         if mail:
             return mail
